@@ -13,13 +13,10 @@
 # limitations under the License.
 
 from pyramid.view import view_config
-from pyramid.httpexceptions import HTTPFound
 
-from sqlalchemy.exc import DBAPIError
-
-from .. import models
 from .. import security
 
+
 @view_config(route_name='home', renderer='../templates/home.pt')
 def my_view(request):
     security.revalidate_user_or_login(request)
